@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # encoding=UTF-8
 # Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
 #
@@ -14,8 +13,8 @@
 import argparse
 import sys
 
-from ocrodjvu import hocr
-from ocrodjvu import version
+from . import hocr
+from . import version
 
 __version__ = version.__version__
 
