@@ -21,6 +21,7 @@ except ImportError:
     from xml.etree import cElementTree as etree
 
 from .. import errors
+from .. import image_io
 from .. import ipc
 from .. import text_zones
 from .. import unicode_support
@@ -174,12 +175,12 @@ def scan(stream, settings):
             stack[-1] += [zone]
         else:
             raise errors.MalformedOcrOutput('unexpected <%s>' % element.tag.encode('ASCII', 'unicode-escape'))
-    return text_zones.Zone(const.TEXT_ZONE_PAGE, text_zones.BBox(1, 1, 1, 1)) # XXX
+    raise errors.MalformedOcrOutput('<page> not found')
 
 class Engine(object):
 
     name = 'gocr'
-    image_format = 'ppm'
+    image_format = image_io.PNM
     output_format = 'gocr.xml'
 
     def __init__(self):
